@@ -512,6 +512,9 @@ func NewPackage(pkgPath string, pkg *ast.Package, conf *Config) (p *gogen.Packag
 	if conf.Recorder != nil {
 		rec = newRecorder(conf.Recorder)
 		confGox.Recorder = rec
+		defer func() {
+			rec.Complete(p.Types.Scope())
+		}()
 	}
 	if enableRecover {
 		defer func() {
@@ -888,19 +891,19 @@ func preloadFile(p *gogen.Package, ctx *blockCtx, f *ast.File, goFile string, ge
 
 	preloadFuncDecl := func(d *ast.FuncDecl) {
 		if ctx.classRecv != nil { // in class file (.spx/.gmx)
-			if d.Recv == nil {
+			if recv := d.Recv; recv == nil || len(recv.List) == 0 {
 				d.Recv = ctx.classRecv
 				d.IsClass = true
 			}
 		}
+		name := d.Name
+		fname := name.Name
 		if d.Recv == nil {
-			name := d.Name
 			fn := func() {
 				old, _ := p.SetCurFile(goFile, true)
 				defer p.RestoreCurFile(old)
-				loadFunc(ctx, nil, d, genFnBody)
+				loadFunc(ctx, nil, fname, d, genFnBody)
 			}
-			fname := name.Name
 			if fname == "init" {
 				if genFnBody {
 					if debugLoad {
@@ -918,18 +921,30 @@ func preloadFile(p *gogen.Package, ctx *blockCtx, f *ast.File, goFile string, ge
 					}
 				}
 			}
-		} else {
-			if name, ok := getRecvTypeName(parent, d.Recv, true); ok {
+		} else if tname, ok := getRecvTypeName(parent, d.Recv, true); ok {
+			if d.Static {
 				if debugLoad {
-					log.Printf("==> Preload method %s.%s\n", name, d.Name.Name)
+					log.Printf("==> Preload static method %s.%s\n", tname, fname)
 				}
-				ld := getTypeLoader(parent, syms, token.NoPos, name)
+				fname = staticMethod(tname, fname)
+				fn := func() {
+					old, _ := p.SetCurFile(goFile, true)
+					defer p.RestoreCurFile(old)
+					loadFunc(ctx, nil, fname, d, genFnBody)
+				}
+				initLoader(parent, syms, name.Pos(), fname, fn, genFnBody)
+				ctx.lbinames = append(ctx.lbinames, fname)
+			} else {
+				if debugLoad {
+					log.Printf("==> Preload method %s.%s\n", tname, fname)
+				}
+				ld := getTypeLoader(parent, syms, token.NoPos, tname)
 				fn := func() {
 					old, _ := p.SetCurFile(goFile, true)
 					defer p.RestoreCurFile(old)
 					doInitType(ld)
 					recv := toRecv(ctx, d.Recv)
-					loadFunc(ctx, recv, d, genFnBody)
+					loadFunc(ctx, recv, fname, d, genFnBody)
 				}
 				ld.methods = append(ld.methods, fn)
 			}
@@ -1068,6 +1083,9 @@ func preloadFile(p *gogen.Package, ctx *blockCtx, f *ast.File, goFile string, ge
 					log.Panicln("TODO - cl.preloadFile OverloadFuncDecl: invalid recv")
 				}
 				recv = otyp
+				if ctx.rec != nil {
+					ctx.rec.Refer(recv, recv.Name)
+				}
 			}
 			onames := make([]string, 0, 4)
 			exov := false
@@ -1079,19 +1097,27 @@ func preloadFile(p *gogen.Package, ctx *blockCtx, f *ast.File, goFile string, ge
 					onames = append(onames, expr.Name)
 					ctx.lbinames = append(ctx.lbinames, expr.Name)
 					exov = true
+					if ctx.rec != nil {
+						ctx.rec.Refer(expr, expr.Name)
+					}
 				case *ast.SelectorExpr:
 					checkOverloadMethod(d)
-					checkOverloadMethodRecvType(recv, expr.X)
+					rtyp := checkOverloadMethodRecvType(recv, expr.X)
 					onames = append(onames, "."+expr.Sel.Name)
 					ctx.lbinames = append(ctx.lbinames, recv)
 					exov = true
+					if ctx.rec != nil {
+						ctx.rec.Refer(rtyp, rtyp.Name)
+						ctx.rec.Refer(expr.Sel, rtyp.Name+"."+expr.Sel.Name)
+					}
 				case *ast.FuncLit:
 					checkOverloadFunc(d)
 					name1 := overloadFuncName(name.Name, idx)
+					onames = append(onames, "") // const Gopo_xxx = "xxxInt,,xxxFloat"
 					ctx.lbinames = append(ctx.lbinames, name1)
 					preloadFuncDecl(&ast.FuncDecl{
 						Doc:  d.Doc,
-						Name: &ast.Ident{NamePos: name.NamePos, Name: name1},
+						Name: &ast.Ident{NamePos: expr.Pos(), Name: name1},
 						Type: expr.Type,
 						Body: expr.Body,
 					})
@@ -1133,12 +1159,13 @@ func checkOverloadMethod(d *ast.OverloadFuncDecl) {
 	}
 }
 
-func checkOverloadMethodRecvType(ot *ast.Ident, recv ast.Expr) {
+func checkOverloadMethodRecvType(ot *ast.Ident, recv ast.Expr) *ast.Ident {
 	rtyp, _ := getRecvType(recv)
 	rt, ok := rtyp.(*ast.Ident)
 	if !ok || ot.Name != rt.Name {
 		log.Panicln("TODO - checkOverloadMethodRecvType:", recv)
 	}
+	return rt
 }
 
 const (
@@ -1168,6 +1195,14 @@ func overloadName(recv *ast.Ident, name string, isOp bool) string {
 	return "Gopo" + sep + typ + name
 }
 
+func staticMethod(tname, name string) string {
+	sep := "_"
+	if strings.ContainsRune(name, '_') || strings.ContainsRune(tname, '_') {
+		sep = "__"
+	}
+	return "Gops" + sep + tname + sep + name
+}
+
 func stringLit(val string) *ast.BasicLit {
 	return &ast.BasicLit{Kind: token.STRING, Value: strconv.Quote(val)}
 }
@@ -1185,8 +1220,7 @@ func aliasType(pkg *types.Package, pos token.Pos, name string, typ types.Type) {
 	pkg.Scope().Insert(o)
 }
 
-func loadFunc(ctx *blockCtx, recv *types.Var, d *ast.FuncDecl, genBody bool) {
-	name := d.Name.Name
+func loadFunc(ctx *blockCtx, recv *types.Var, name string, d *ast.FuncDecl, genBody bool) {
 	if debugLoad {
 		if recv == nil {
 			log.Println("==> Load func", name)
@@ -1234,7 +1268,7 @@ func loadFunc(ctx *blockCtx, recv *types.Var, d *ast.FuncDecl, genBody bool) {
 	commentFunc(ctx, fn, d)
 	if rec := ctx.recorder(); rec != nil {
 		rec.Def(d.Name, fn.Func)
-		if recv == nil && d.Name.Name != "_" {
+		if recv == nil && name != "_" {
 			ctx.fileScope.Insert(fn.Func)
 		}
 	}
